pub enum RuleBodyItem {
Decl(Declaration),
Rule(Rule),
}Expand description
This enum represents the fact that a rule body can be either a declaration or a nested rule.
Variants
Decl(Declaration)
Rule(Rule)