pub struct Stylesheet {
origin: Origin,
qualified_rules: Vec<QualifiedRule>,
}Expand description
A parsed CSS stylesheet.
Fields
origin: Originqualified_rules: Vec<QualifiedRule>Implementations
Sourceimpl Stylesheet
impl Stylesheet
fn empty(origin: Origin) -> Stylesheet
Sourcepub fn from_data(
buf: &str,
url_resolver: &UrlResolver,
origin: Origin,
session: Session,
) -> Result<Self, LoadingError>
pub fn from_data( buf: &str, url_resolver: &UrlResolver, origin: Origin, session: Session, ) -> Result<Self, LoadingError>
Parses a new stylesheet from CSS data in a string.
The url_resolver_url is required for @import rules, so that librsvg can determine if
the requested path is allowed.
Sourcepub fn from_href(
aurl: &AllowedUrl,
origin: Origin,
session: Session,
) -> Result<Self, LoadingError>
pub fn from_href( aurl: &AllowedUrl, origin: Origin, session: Session, ) -> Result<Self, LoadingError>
Parses a new stylesheet by loading CSS data from a URL.
Sourcefn add_rules_from_string(
&mut self,
buf: &str,
url_resolver: &UrlResolver,
session: Session,
) -> Result<(), LoadingError>
fn add_rules_from_string( &mut self, buf: &str, url_resolver: &UrlResolver, session: Session, ) -> Result<(), LoadingError>
Parses the CSS rules in buf and appends them to the stylesheet.
The url_resolver_url is required for @import rules, so that librsvg can determine if
the requested path is allowed.
If there is an @import rule, its rules will be recursively added into the
stylesheet, in the order in which they appear.
Sourcefn load(
&mut self,
aurl: &AllowedUrl,
session: Session,
) -> Result<(), LoadingError>
fn load( &mut self, aurl: &AllowedUrl, session: Session, ) -> Result<(), LoadingError>
Parses a stylesheet referenced by an URL